============================
Key Manager service overview
============================

The Key Manager service provides secure storage, provisioning and management of
secrets, such as passwords, encryption keys, etc.

The Key Manager service consists of the following components:

``barbican-api`` service
  Provides an OpenStack-native RESTful API that supports provisioning and managing
  Barbican secrets.
